<?php

namespace Drupal\Tests\tmgmt_smartling\Kernel;

/**
 * Tests base flows.
 *
 * @group tmgmt_smartling
 */
class BaseFlowTest extends SmartlingTestBase {

  private $apiWrapperMock;

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $api_factory_mock = $this->getMockBuilder('\Drupal\tmgmt_smartling\Smartling\SmartlingApiFactory')
      ->setMethods(NULL)
      ->getMock();

    $logger_mock = $this->getMockBuilder('\Drupal\Core\Logger\LoggerChannel')
      ->setMethods(NULL)
      ->disableOriginalConstructor()
      ->getMock();

    $this->apiWrapperMock = $this->getMockBuilder('\Drupal\tmgmt_smartling\Smartling\SmartlingApiWrapper')
      ->setMethods(['deleteFile'])
      ->setConstructorArgs([$api_factory_mock, $logger_mock])
      ->getMock();

    \Drupal::getContainer()->set('tmgmt_smartling.smartling_api_wrapper', $this->apiWrapperMock);
  }

  /**
   * Delete file in Smartling dashboard when corresponding TMGMT job is deleted.
   */
  function testJobFileDeletionInDashboardSuccess() {
    $this->apiWrapperMock->expects($this->once())
      ->method('deleteFile')
      ->with('JobID1_en_de.xml');

    $translate_job = $this->createJobWithItems([]);
    $translate_job->delete();
  }

  /**
   * Delete file in Smartling dashboard when corresponding TMGMT job is deleted.
   *
   * No translator assigned to the job.
   */
  function testJobFileDeletionInDashboardNoTranslatorAssigned() {
    $this->apiWrapperMock->expects($this->never())
      ->method('deleteFile');

    $translate_job = $this->createJobWithItems([], NULL);
    $translate_job->delete();
  }

  /**
   * Delete file in Smartling dashboard when corresponding TMGMT job is deleted.
   *
   * Not smartling translator assigned to the job.
   */
  function testJobFileDeletionInDashboardNotSmartlingTranslatorAssigned() {
    $this->apiWrapperMock->expects($this->never())
      ->method('deleteFile');

    $translate_job = $this->createJobWithItems([], $this->default_translator->id());
    $translate_job->delete();
  }
}
